summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xbuild/instack.sh3
-rwxr-xr-xci/deploy.sh4
2 files changed, 4 insertions, 3 deletions
diff --git a/ci/deploy.sh b/ci/deploy.sh
index 5118aea1..d96ebe4f 100755
--- a/ci/deploy.sh
+++ b/ci/deploy.sh
@@ -824,8 +824,8 @@ openstack overcloud image upload
echo "Configuring undercloud and discovering nodes"
openstack baremetal import --json instackenv.json
openstack baremetal configure boot
-if [[ -z "$virtual" ]]; then
-openstack baremetal introspection bulk start
+if [[ -z "$virtual" ]]; then
+ openstack baremetal introspection bulk start
fi
echo "Configuring flavors"
for flavor in baremetal control compute; do
diff --git a/build/instack.sh b/build/instack.sh
index d7109c55..03dfd1ef 100755
--- a/build/instack.sh
+++ b/build/instack.sh
@@ -253,12 +253,13 @@ git checkout stable/liberty
popd
tar -czf puppet-aodh.tar.gz aodh
# Add epel, aodh and ceph, remove openstack-neutron-openvswitch
AODH_PKG="openstack-aodh-api,openstack-aodh-common,openstack-aodh-compat,openstack-aodh-evaluator,openstack-aodh-expirer"
AODH_PKG+=",openstack-aodh-listener,openstack-aodh-notifier"
LIBGUESTFS_BACKEND=direct virt-customize --upload puppet-aodh.tar.gz:/etc/puppet/modules/ \
--run-command "cd /etc/puppet/modules/ && rm -rf aodh && tar xzf puppet-aodh.tar.gz" \
--run-command "yum remove -y openstack-neutron-openvswitch" \
+ --run-command "echo 'nf_conntrack_proto_sctp' > /etc/modules-load.d/nf_conntrack_proto_sctp.conf" \
--install https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm \
--install "$AODH_PKG,ceph" \
-a overcloud-full-opendaylight.qcow2
@@ -253,12 +253,13 @@ git checkout stable/liberty
popd
tar -czf puppet-aodh.tar.gz aodh
-# Add epel, aodh and ceph, remove openstack-neutron-openvswitch
+# Add epel, aodh and ceph, remove openstack-neutron-openvswitch, add sctp module
AODH_PKG="openstack-aodh-api,openstack-aodh-common,openstack-aodh-compat,openstack-aodh-evaluator,openstack-aodh-expirer"
AODH_PKG+=",openstack-aodh-listener,openstack-aodh-notifier"